pub struct ClockOut<'a> { /* private fields */ }Expand description
A peripheral representing the CLKOUT pseudo-peripheral
Implementations
Sourceimpl<'a> ClockOut<'a>
impl<'a> ClockOut<'a>
Sourcepub fn new(
_peri: Peri<'a, CLKOUT>,
pin: Peri<'a, impl ClockOutPin>,
cfg: Config,
) -> Result<Self, ClockError>
pub fn new( _peri: Peri<'a, CLKOUT>, pin: Peri<'a, impl ClockOutPin>, cfg: Config, ) -> Result<Self, ClockError>
Create a new ClockOut pin. On success, the clock signal will begin immediately on the given pin.
Any external pin will be placed into Disabled state upon Drop.
Sourcepub unsafe fn new_unchecked(
_peri: Peri<'a, CLKOUT>,
pin: Peri<'a, impl ClockOutPin>,
cfg: Config,
) -> Result<Self, ClockError>
pub unsafe fn new_unchecked( _peri: Peri<'a, CLKOUT>, pin: Peri<'a, impl ClockOutPin>, cfg: Config, ) -> Result<Self, ClockError>
Unsafe constructor that ignores PoweredClock checks and discards WakeGuards
Only intended for debugging low power clock gating, to ensure that clocks start/stop appropriately.
SAFETY
The caller must not rely on the clock running for correctness if the provided clock will be gated in deep sleep mode.